@@ -265,8 +265,10 @@ public class MainWindow {
 	private JLabel predictionLabel = new JLabel(""); //$NON-NLS-1$
 
 	//bottom panel components
+    @SuppressWarnings("rawtypes")
 	private DefaultListModel notesListModel;
-	private JList notesDatesList;
+    @SuppressWarnings("rawtypes")
+    private JList notesDatesList;
 	private JTextArea notesTextArea;
 	private JSplitPane notesSplitPane;
 
@@ -393,7 +395,8 @@ public class MainWindow {
 				JOptionPane.WARNING_MESSAGE);
 	}
 
-	private void createMainPanel() {
+	@SuppressWarnings({ "rawtypes", "unchecked" })
+    private void createMainPanel() {
 		// define the sub-panels
 		JPanel masterPanel = new JPanel(new GridBagLayout());
 		JPanel leftPanel = new JPanel(new GridBagLayout());
@@ -1194,7 +1197,8 @@ public class MainWindow {
 	 * This method reloads the notes from the engine. If the current calendar date matches some note from the list, 
 	 * such note is highlighted
 	 */
-	private void refreshNotes() {
+	@SuppressWarnings("unchecked")
+    private void refreshNotes() {
 		TreeSet<Date> notes_dates = new TreeSet<Date>(PCalendar.engine.getNoteDates());
 		notesListModel.clear();
 
