@@ -116,14 +116,22 @@ public class Engine {
 	private static final String FILE_PROPERTIES_TAG = "FileProperties"; //$NON-NLS-1$
 
 	private static final String CELSIUS_SCALE = "CELSIUS_SCALE"; //$NON-NLS-1$
+	private static final String SCALE_TEMP_MAX = "SCALE_TEMP_MAX"; //$NON-NLS-1$
+	private static final String SCALE_TEMP_MIN = "SCALE_TEMP_MIN"; //$NON-NLS-1$
 	private static final String TRUE = "True"; 					//$NON-NLS-1$
 	private static final String FALSE = "False";				//$NON-NLS-1$
-
+    public static final int DEFAULT_BBT_TEMPERATURE_MIN_C = 360; // default minimum temperature
+    public static final int DEFAULT_BBT_TEMPERATURE_MIN_F = 968;
+	
 	private TreeSet<Date> startDates = new TreeSet<Date>(); /// the calendar events index
 	private HashMap<Date, Integer> dateTypes = new HashMap<Date, Integer>(); /// the types of the calendar events listed in start_dates
 	private HashMap<Date, String> notesContainer = new HashMap<Date, String>(); /// the notes container
 	private HashMap<Date, Integer> bBTList = new HashMap<Date, Integer>(); /// the BBT records list
 	private boolean fileBBTCelsiusScale = true; // if true - the file contains BBT records in the Celsius scale, otherwise - in Fahrenheit
+	private static final int DEFAULT_BBT_TEMPERATURE_LEVELS_C = 16;
+	private static final int DEFAULT_BBT_TEMPERATURE_LEVELS_F = 29;
+	private int minTempScale = DEFAULT_BBT_TEMPERATURE_MIN_C; // minimum temperature on a graph scale 
+	private int maxTempScale = DEFAULT_BBT_TEMPERATURE_MIN_C + DEFAULT_BBT_TEMPERATURE_LEVELS_C-1; // maximum temperature on a graph scale 
 	private HashMap<Date, DateIntsContainer> dateIntValues = new HashMap<Date, DateIntsContainer>(); /// the date-value container for the integer values
 	private BBTSympthomsSetDefinition sympthomsDefinition = new BBTSympthomsSetDefinition(); // the container for the additional sympthoms list to be monitored
 	private HashMap<Integer, String> dateTypeToTagMap = new HashMap<Integer, String>(); /// map the date type code to the tag name
@@ -796,6 +804,23 @@ public class Engine {
 		}
 		String celsiusScale = fileProperties.getProperty(CELSIUS_SCALE, TRUE);
 		fileBBTCelsiusScale = celsiusScale.equals(TRUE);
+		
+		String minTempScaleString = fileProperties.getProperty(SCALE_TEMP_MIN, ""); //$NON-NLS-1$
+		String maxTempScaleString = fileProperties.getProperty(SCALE_TEMP_MAX, ""); //$NON-NLS-1$
+		
+		if(minTempScaleString.equals("")) { //$NON-NLS-1$
+		    minTempScale = fileBBTCelsiusScale?DEFAULT_BBT_TEMPERATURE_MIN_C:DEFAULT_BBT_TEMPERATURE_MIN_F; 
+		} else {
+		    minTempScale = Integer.parseInt(minTempScaleString);
+		}
+		
+        if(maxTempScaleString.equals("")) { //$NON-NLS-1$
+            maxTempScale = fileBBTCelsiusScale?
+                    (DEFAULT_BBT_TEMPERATURE_MIN_C+DEFAULT_BBT_TEMPERATURE_LEVELS_C)
+                    :(DEFAULT_BBT_TEMPERATURE_MIN_F+DEFAULT_BBT_TEMPERATURE_LEVELS_F); 
+        } else {
+            maxTempScale = Integer.parseInt(maxTempScaleString);
+        }
 	}
 
 	/**
@@ -991,6 +1016,8 @@ public class Engine {
 		}
 
 		fileProperties.setProperty(CELSIUS_SCALE, fileBBTCelsiusScale?TRUE:FALSE);
+		fileProperties.setProperty(SCALE_TEMP_MIN, String.valueOf(minTempScale));
+		fileProperties.setProperty(SCALE_TEMP_MAX, String.valueOf(maxTempScale));
 
 		ByteArrayOutputStream bas = new ByteArrayOutputStream();
 		fileProperties.store(bas, ""); //$NON-NLS-1$
@@ -1568,6 +1595,9 @@ public class Engine {
 					convertTemperatureScale(toCelsiusScale, bBTList.get(date)));
 		}
 
+		minTempScale = convertTemperatureScale(toCelsiusScale, minTempScale);
+		maxTempScale = convertTemperatureScale(toCelsiusScale, maxTempScale);
+
 		fileBBTCelsiusScale = toCelsiusScale;
 		modified = true;
 	}
@@ -1594,8 +1624,49 @@ public class Engine {
 	public boolean isFileBBTCelsiusScale() {
 		return fileBBTCelsiusScale;
 	}
-
+	
 	/**
+	 * Returns the minumum of the temperature scale
+     * @return the minTempScale
+     */
+    public int getMinTempScale() {
+        return minTempScale;
+    }
+
+    /**
+     * Sets minimum for the temperature scale
+     * @param minTempScale the minTempScale to set
+     */
+    public void setMinTempScale(int minTempScale) {
+        this.minTempScale = minTempScale;
+        modified = true;
+    }
+
+    /**
+     * Gets maximum for the temperature scale
+     * @return the maxTempScale
+     */
+    public int getMaxTempScale() {
+        return maxTempScale;
+    }
+
+    /**
+     * Sets maximum for the temperature scalse
+     * @param maxTempScale the maxTempScale to set
+     */
+    public void setMaxTempScale(int maxTempScale) {
+        this.maxTempScale = maxTempScale;
+        modified = true;
+    }
+    
+    /**
+     * @return temperature levels count according to the current temperatures range selection
+     */
+    public int getBBTTemperatureLevelsCount () {
+        return maxTempScale - minTempScale + 1;
+    }
+
+    /**
 	 * @return the default engine preferences
 	 */
 	public EnginePreferences getDefaultPreferences() {
